local OptionObjects={}
local LSM = HealBot_Libs_LSM()
local HealBot_Plugin_luVars={}
local HealBot_Plugin_Functions={}
local HealBot_Plugin_Config={}
local HealBot_Plugin={}
local HealBot_Plugin_ColourList={}
local HealBot_Plugin_FontOutlineList={}
local HealBot_Bar_Textures=nil
local HealBot_Fonts=nil
local HealBot_Bar_TexturesIndex={}
local HealBot_FontsIndex={}

function HealBot_Plugin_Options_Performance()
	HealBot_Plugin_luVars["pluginId"]="Performance"
    HealBot_Plugin_luVars["addonId"]="HealBot_Plugin_Performance"
	HealBot_Plugin_luVars["OptionsFrame"]=HealBot_Options_PluginPerformanceFrame
	
	HealBot_Plugin_Functions["pluginShutdown"]=HealBot_Plugin_Performance_Shutdown
	HealBot_Plugin_Functions["updateAll"]=HealBot_Plugin_Performance_UpdateAll

	HealBot_Plugin_Config=HealBot_Plugin_Performance_Config
	HealBot_Plugin=HealBot_Plugin_Performance
end

local function HealBot_Plugin_InUse()
	if HealBot_Globals.PluginPerformance then
        OptionObjects["OptionFrame"]:Show()
	else
		OptionObjects["OptionFrame"]:Hide()
	end
end

local function HealBot_Plugin_OnClick(self)
	if self:GetChecked() then
		HealBot_Globals.PluginPerformance=true
		HealBot_Plugin_Performance_Init()
	else
		HealBot_Globals.PluginPerformance=false
		HealBot_Plugin_Performance_Shutdown()
	end
	HealBot_Plugin_InUse()
	HealBot_InitPlugins()
end

--------------------------------------------------------------------

local function HealBot_Plugin_Options_SetupFrame(frame, hide)
	frame:SetBackdrop({
		bgFile = "Interface\\Tooltips\\UI-Tooltip-Background",
		edgeFile = "Interface\\Tooltips\\UI-Tooltip-Border",
		tile = true, tileSize = 8, edgeSize = 8,
		insets = { left = 0, right = 0, top = 0, bottom = 0, },
	})
	frame:SetBackdropColor(0,0,0,0);
	frame:SetPoint("TOPLEFT", -5, -120)
	frame:SetSize(600,470)
	if hide then
		frame:Hide()
	else 
		HealBot_Plugin_luVars["prevFrame"]=frame
	end
    frame.Txt = frame:CreateFontString()
    frame.Txt:SetFontObject(GameFontNormal)
    frame.Txt:SetPoint("BOTTOMRIGHT", -5 , 5)
end

local function HealBot_Plugin_Options_SetLabel(object, text)
	local r,g,b,a=HealBot_Options_OptionsThemeCols()
	object:SetText(text)
	object:SetTextColor(r,g,b,a)
end

local function HealBot_Plugin_Options_SetupSlider(slider, point, width, x, y)
	slider:SetSize(width, 15)
	slider:SetOrientation('HORIZONTAL')
	slider:SetPoint(point, x, y)
end

local function HealBot_Plugin_OptionInternalTimer_OnValueChanged(self)
    local val=floor(self:GetValue()+0.5)
    if val~=self:GetValue() then
        self:SetValue(val) 
    elseif HealBot_Plugin_Config.cpuAdj[HealBot_Plugin.Profile]~=val then
		HealBot_Plugin_Config.cpuAdj[HealBot_Plugin.Profile] = val;
		HealBot_Plugin_Functions["updateAll"]()
    end
end

local function HealBot_Plugin_OptionFluidFreq_OnValueChanged(self)
    local val=floor(self:GetValue()+0.5)
    if val~=self:GetValue() then
        self:SetValue(val) 
    elseif HealBot_Plugin_Config.FluidFreqAdj[HealBot_Plugin.Profile]~=val then
		HealBot_Plugin_Config.FluidFreqAdj[HealBot_Plugin.Profile] = val;
		HealBot_Plugin_Functions["updateAll"]()
    end
end

local function HealBot_Plugin_OptionFlashFreq_OnValueChanged(self)
    local val=floor(self:GetValue()+0.5)
    if val~=self:GetValue() then
        self:SetValue(val) 
    elseif HealBot_Plugin_Config.FlashFreqAdj[HealBot_Plugin.Profile]~=val then
		HealBot_Plugin_Config.FlashFreqAdj[HealBot_Plugin.Profile] = val;
		HealBot_Plugin_Functions["updateAll"]()
    end
end

local function HealBot_Plugin_OptionStateFreq_OnValueChanged(self)
    local val=floor(self:GetValue()+0.5)
    if val~=self:GetValue() then
        self:SetValue(val) 
    elseif HealBot_Plugin_Config.StateFreqAdj[HealBot_Plugin.Profile]~=val then
		HealBot_Plugin_Config.StateFreqAdj[HealBot_Plugin.Profile] = val;
		HealBot_Plugin_Functions["updateAll"]()
    end
end

local function HealBot_Plugin_Frame_Profile(self)
	if self:GetChecked() then
		HealBot_Plugin.Profile="Global"
	else
		HealBot_Plugin.Profile=UnitName("player")
		table.foreach(HealBot_Plugin_Config, function (key,val)
			if HealBot_Plugin_Config[key][HealBot_Plugin.Profile]==nil then
				HealBot_Plugin_Config[key][HealBot_Plugin.Profile] = HealBot_Plugin_Config[key]["Global"];
			end
		end)
	end
	HealBot_Plugin_Functions["updateAll"]()
	HealBot_Plugin_Threat_Options()
end

local function HealBot_Plugin_Options()
	local pId=HealBot_Plugin_luVars["pluginId"]
	if not HealBot_Plugin_luVars["optionsInit"] then
        HealBot_Bar_Textures = LSM:List('statusbar');
        for x,_ in pairs(HealBot_Bar_TexturesIndex) do
            HealBot_Bar_TexturesIndex[x]=nil
        end 
        for i=1,#HealBot_Bar_Textures do
            HealBot_Bar_TexturesIndex[HealBot_Bar_Textures[i]] = i
        end
        HealBot_Fonts = LSM:List('font');
        for x,_ in pairs(HealBot_FontsIndex) do
            HealBot_FontsIndex[x]=nil
        end 
        for i=1,#HealBot_Fonts do
            HealBot_FontsIndex[HealBot_Fonts[i]] = i
        end
		
		OptionObjects["OptionFrame"] = CreateFrame("Frame", "HealBot_"..pId.."_Options_Frame", HealBot_Plugin_luVars["OptionsFrame"], BackdropTemplateMixin and "BackdropTemplate")
		HealBot_Plugin_Options_SetupFrame(OptionObjects["OptionFrame"])
        
		-- Frame
		OptionObjects["OptionFrameProfile"] = CreateFrame("CheckButton", "HealBot_"..pId.."_Profile", OptionObjects["OptionFrame"], "OptionsCheckButtonTemplate")
		OptionObjects["OptionFrameProfile"]:SetPoint("TOP", -40, -50)
		OptionObjects["OptionFrameProfile"]:SetScript("OnClick", function() HealBot_Plugin_Frame_Profile(OptionObjects["OptionFrameProfile"]); end)

		OptionObjects["OptionInternalTimer"] = CreateFrame("Slider", "HealBot_"..pId.."_Options_Timers", OptionObjects["OptionFrame"], "OptionsSliderTemplate")
		HealBot_Plugin_Options_SetupSlider(OptionObjects["OptionInternalTimer"], "TOP", 500, 0, -150)
		OptionObjects["OptionInternalTimer"]:SetScript("OnValueChanged", function() HealBot_Plugin_OptionInternalTimer_OnValueChanged(OptionObjects["OptionInternalTimer"]); end)
        
		OptionObjects["OptionFluidFreq"] = CreateFrame("Slider", "HealBot_"..pId.."_Options_Fluid", OptionObjects["OptionFrame"], "OptionsSliderTemplate")
		HealBot_Plugin_Options_SetupSlider(OptionObjects["OptionFluidFreq"], "TOP", 500, 0, -230)
		OptionObjects["OptionFluidFreq"]:SetScript("OnValueChanged", function() HealBot_Plugin_OptionFluidFreq_OnValueChanged(OptionObjects["OptionFluidFreq"]); end)
        
		OptionObjects["OptionFlashFreq"] = CreateFrame("Slider", "HealBot_"..pId.."_Options_Flash", OptionObjects["OptionFrame"], "OptionsSliderTemplate")
		HealBot_Plugin_Options_SetupSlider(OptionObjects["OptionFlashFreq"], "TOP", 500, 0, -310)
		OptionObjects["OptionFlashFreq"]:SetScript("OnValueChanged", function() HealBot_Plugin_OptionFlashFreq_OnValueChanged(OptionObjects["OptionFlashFreq"]); end)
        
		OptionObjects["OptionStateFreq"] = CreateFrame("Slider", "HealBot_"..pId.."_Options_State", OptionObjects["OptionFrame"], "OptionsSliderTemplate")
		HealBot_Plugin_Options_SetupSlider(OptionObjects["OptionStateFreq"], "TOP", 500, 0, -390)
		OptionObjects["OptionStateFreq"]:SetScript("OnValueChanged", function() HealBot_Plugin_OptionStateFreq_OnValueChanged(OptionObjects["OptionStateFreq"]); end)
        
		HealBot_Plugin_luVars["optionsInit"]=true
	end
	local r,g,b=HealBot_Options_OptionsThemeCols()
	HealBot_Options_SetText(OptionObjects["OptionUse"], " Enable Plugin")
	HealBot_Options_SetText(OptionObjects["OptionFrameProfile"], HEALBOT_WORDS_GLOBALPROFILE)
    HealBot_Options_sliderlabels_Init(OptionObjects["OptionInternalTimer"],HEALBOT_OPTIONS_INTTIMER,1,7,1,2,HEALBOT_WORDS_LESSCPU,HEALBOT_WORDS_MORECPU)
	OptionObjects["OptionInternalTimer"]:SetValue(HealBot_Plugin_Config.cpuAdj[HealBot_Plugin.Profile])
	HealBot_Options_SetText(OptionObjects["OptionInternalTimer"],HEALBOT_OPTIONS_INTTIMER)
    HealBot_Options_sliderlabels_Init(OptionObjects["OptionFluidFreq"],HEALBOT_OPTIONS_FLUIDFREQ,1,7,1,2,HEALBOT_WORDS_LESSCPU,HEALBOT_WORDS_MORECPU)
	OptionObjects["OptionFluidFreq"]:SetValue(HealBot_Plugin_Config.FluidFreqAdj[HealBot_Plugin.Profile])
	HealBot_Options_SetText(OptionObjects["OptionFluidFreq"],HEALBOT_OPTIONS_FLUIDFREQ)
    HealBot_Options_sliderlabels_Init(OptionObjects["OptionFlashFreq"],HEALBOT_OPTIONS_FLASHFREQ,1,7,1,2,HEALBOT_WORDS_LESSCPU,HEALBOT_WORDS_MORECPU)
	OptionObjects["OptionFlashFreq"]:SetValue(HealBot_Plugin_Config.FlashFreqAdj[HealBot_Plugin.Profile])
	HealBot_Options_SetText(OptionObjects["OptionFlashFreq"],HEALBOT_OPTIONS_FLASHFREQ)
    HealBot_Options_sliderlabels_Init(OptionObjects["OptionStateFreq"],HEALBOT_OPTIONS_STATEFREQ,1,7,1,2,HEALBOT_WORDS_LESSCPU,HEALBOT_WORDS_MORECPU)
	OptionObjects["OptionStateFreq"]:SetValue(HealBot_Plugin_Config.StateFreqAdj[HealBot_Plugin.Profile])
	HealBot_Options_SetText(OptionObjects["OptionStateFreq"],HEALBOT_OPTIONS_STATEFREQ)
    HealBot_Plugin_Options_SetLabel(OptionObjects["OptionFrame"].Txt, HEALBOT_WORD_VERSION..": "..HealBot_Plugin_luVars["Version"])
	if HealBot_Plugin.Profile=="Global" then
		OptionObjects["OptionFrameProfile"]:SetChecked(true)
	else
		OptionObjects["OptionFrameProfile"]:SetChecked(false)
	end

	OptionObjects["OptionFrame"]:SetBackdropBorderColor(r,g,b,0.7)
end

function HealBot_Plugin_Performance_Options()
	HealBot_Plugin_Options_Performance()
	if not HealBot_Plugin_luVars["optionsInit"] then
        HealBot_Plugin_luVars["Version"] = GetAddOnMetadata(HealBot_Plugin_luVars["addonId"], "Version") or 0
		local pId=HealBot_Plugin_luVars["pluginId"]
		OptionObjects["OptionUse"] = CreateFrame("CheckButton", "HealBot_"..pId.."_Frame_Use", HealBot_Plugin_luVars["OptionsFrame"], "OptionsCheckButtonTemplate")
		OptionObjects["OptionUse"]:SetPoint("TOP", -40, -40)
		OptionObjects["OptionUse"]:SetScript("OnClick", function() HealBot_Plugin_OnClick(OptionObjects["OptionUse"]); end)
		OptionObjects["OptionUse"]:SetChecked(HealBot_Globals.PluginPerformance)		
	end
	HealBot_Plugin_Options()
	HealBot_Plugin_InUse()
end